/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IFluidCodeDetails, IFluidRouter, IFluidRunnable, IRequest, IResponse } from "@fluidframework/core-interfaces";
import { IContainer, IHostLoader, ILoaderOptions } from "@fluidframework/container-definitions";
import { IFluidResolvedUrl } from "@fluidframework/driver-definitions";
import * as Comlink from "comlink";
interface IProxyLoader extends IHostLoader, IFluidRunnable {
    new (id: string, options: ILoaderOptions, resolved: IFluidResolvedUrl, fromSequenceNumber: number): IProxyLoader;
    stop(reason?: string): Promise<void>;
}
/**
 * Proxies requests to web worker loader.
 */
export declare class WebWorkerLoader implements IHostLoader, IFluidRunnable, IFluidRouter {
    private readonly proxy;
    static load(id: string, options: ILoaderOptions, resolved: IFluidResolvedUrl, fromSequenceNumber: number): Promise<WebWorkerLoader>;
    constructor(proxy: Comlink.Remote<IProxyLoader>);
    get IFluidRouter(): this;
    get IFluidRunnable(): this;
    request(request: IRequest): Promise<IResponse>;
    run(...args: any[]): Promise<void>;
    stop(reason?: string): Promise<void>;
    resolve(request: IRequest, pendingLocalState?: string): Promise<IContainer>;
    createDetachedContainer(source: IFluidCodeDetails): Promise<IContainer>;
    rehydrateDetachedContainerFromSnapshot(source: string): Promise<IContainer>;
}
export {};
//# sourceMappingURL=webWorkerLoader.d.ts.map